mocks

package
v0.0.0-...-79350a0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 10, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConfigOption

type ConfigOption struct {
	mock.Mock
}

ConfigOption is an autogenerated mock type for the ConfigOption type

func NewConfigOption

func NewConfigOption(t mockConstructorTestingTNewConfigOption) *ConfigOption

NewConfigOption creates a new instance of ConfigOption. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*ConfigOption) Execute

func (_m *ConfigOption) Execute(_a0 context.Context, _a1 *config.Config)

Execute provides a mock function with given fields: _a0, _a1

type Iterator

type Iterator struct {
	mock.Mock
}

Iterator is an autogenerated mock type for the Iterator type

func NewIterator

func NewIterator(t mockConstructorTestingTNewIterator) *Iterator

NewIterator creates a new instance of Iterator. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*Iterator) Next

func (_m *Iterator) Next() (*node.Node, error)

Next provides a mock function with given fields:

type NewClient

type NewClient struct {
	mock.Mock
}

NewClient is an autogenerated mock type for the NewClient type

func NewNewClient

func NewNewClient(t mockConstructorTestingTNewNewClient) *NewClient

NewNewClient creates a new instance of NewClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*NewClient) Execute

func (_m *NewClient) Execute(_a0 notionapi.Token, _a1 ...notionapi.ClientOption) *notionapi.Client

Execute provides a mock function with given fields: _a0, _a1

type NotionClient

type NotionClient struct {
	mock.Mock
}

NotionClient is an autogenerated mock type for the NotionClient type

func NewNotionClient

func NewNotionClient(t mockConstructorTestingTNewNotionClient) *NotionClient

NewNotionClient creates a new instance of NotionClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*NotionClient) AppendBlocksToBlock

AppendBlocksToBlock provides a mock function with given fields: _a0, _a1, _a2

func (*NotionClient) AppendBlocksToPage

AppendBlocksToPage provides a mock function with given fields: _a0, _a1, _a2

func (*NotionClient) CreateDatabase

CreateDatabase provides a mock function with given fields: _a0, _a1

func (*NotionClient) CreatePage

CreatePage provides a mock function with given fields: _a0, _a1

func (*NotionClient) GetAllDatabases

func (_m *NotionClient) GetAllDatabases(_a0 context.Context, _a1 notionapi.Cursor) ([]notionapi.Database, notionapi.Cursor, error)

GetAllDatabases provides a mock function with given fields: _a0, _a1

func (*NotionClient) GetAllPages

func (_m *NotionClient) GetAllPages(_a0 context.Context, _a1 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)

GetAllPages provides a mock function with given fields: _a0, _a1

func (*NotionClient) GetBlockByID

func (_m *NotionClient) GetBlockByID(_a0 context.Context, _a1 notionclient.BlockID) (notionapi.Block, error)

GetBlockByID provides a mock function with given fields: _a0, _a1

func (*NotionClient) GetChildBlocksOfBlock

func (_m *NotionClient) GetChildBlocksOfBlock(_a0 context.Context, _a1 notionclient.BlockID, _a2 notionapi.Cursor) ([]notionapi.Block, notionapi.Cursor, error)

GetChildBlocksOfBlock provides a mock function with given fields: _a0, _a1, _a2

func (*NotionClient) GetDatabaseByID

func (_m *NotionClient) GetDatabaseByID(_a0 context.Context, _a1 notionclient.DatabaseID) (*notionapi.Database, error)

GetDatabaseByID provides a mock function with given fields: _a0, _a1

func (*NotionClient) GetDatabasePages

GetDatabasePages provides a mock function with given fields: _a0, _a1, _a2

func (*NotionClient) GetDatabasesByName

GetDatabasesByName provides a mock function with given fields: _a0, _a1, _a2

func (*NotionClient) GetPageBlocks

GetPageBlocks provides a mock function with given fields: _a0, _a1, _a2

func (*NotionClient) GetPageByID

func (_m *NotionClient) GetPageByID(_a0 context.Context, _a1 notionclient.PageID) (*notionapi.Page, error)

GetPageByID provides a mock function with given fields: _a0, _a1

func (*NotionClient) GetPagesByName

GetPagesByName provides a mock function with given fields: _a0, _a1, _a2

type ReaderWriter

type ReaderWriter struct {
	mock.Mock
}

ReaderWriter is an autogenerated mock type for the ReaderWriter type

func NewReaderWriter

func NewReaderWriter(t mockConstructorTestingTNewReaderWriter) *ReaderWriter

NewReaderWriter creates a new instance of ReaderWriter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*ReaderWriter) CleanUp

func (_m *ReaderWriter) CleanUp(_a0 context.Context) error

CleanUp provides a mock function with given fields: _a0

func (*ReaderWriter) GetStorageConfig

func (_m *ReaderWriter) GetStorageConfig(_a0 context.Context) (*metadata.StorageConfig, error)

GetStorageConfig provides a mock function with given fields: _a0

func (*ReaderWriter) ReadBlock

func (_m *ReaderWriter) ReadBlock(_a0 context.Context, _a1 rw.DataIdentifier) (notionapi.Block, error)

ReadBlock provides a mock function with given fields: _a0, _a1

func (*ReaderWriter) ReadDatabase

func (_m *ReaderWriter) ReadDatabase(_a0 context.Context, _a1 rw.DataIdentifier) (*notionapi.Database, error)

ReadDatabase provides a mock function with given fields: _a0, _a1

func (*ReaderWriter) ReadPage

func (_m *ReaderWriter) ReadPage(_a0 context.Context, _a1 rw.DataIdentifier) (*notionapi.Page, error)

ReadPage provides a mock function with given fields: _a0, _a1

func (*ReaderWriter) WriteBlock

func (_m *ReaderWriter) WriteBlock(_a0 context.Context, _a1 notionapi.Block) (rw.DataIdentifier, error)

WriteBlock provides a mock function with given fields: _a0, _a1

func (*ReaderWriter) WriteDatabase

func (_m *ReaderWriter) WriteDatabase(_a0 context.Context, _a1 *notionapi.Database) (rw.DataIdentifier, error)

WriteDatabase provides a mock function with given fields: _a0, _a1

func (*ReaderWriter) WriteMetaData

func (_m *ReaderWriter) WriteMetaData(_a0 context.Context, _a1 *metadata.MetaData) error

WriteMetaData provides a mock function with given fields: _a0, _a1

func (*ReaderWriter) WritePage

func (_m *ReaderWriter) WritePage(_a0 context.Context, _a1 *notionapi.Page) (rw.DataIdentifier, error)

WritePage provides a mock function with given fields: _a0, _a1

type TreeBuilder

type TreeBuilder struct {
	mock.Mock
}

TreeBuilder is an autogenerated mock type for the TreeBuilder type

func NewTreeBuilder

func NewTreeBuilder(t mockConstructorTestingTNewTreeBuilder) *TreeBuilder

NewTreeBuilder creates a new instance of TreeBuilder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*TreeBuilder) BuildTree

func (_m *TreeBuilder) BuildTree(_a0 context.Context) (*tree.Tree, error)

BuildTree provides a mock function with given fields: _a0

Jump to