Documentation
¶
Index ¶
- type ConfigOption
- type Iterator
- type NewClient
- type NotionClient
- func (_m *NotionClient) AppendBlocksToBlock(_a0 context.Context, _a1 notionclient.BlockID, ...) (*notionapi.AppendBlockChildrenResponse, error)
- func (_m *NotionClient) AppendBlocksToPage(_a0 context.Context, _a1 notionclient.PageID, ...) (*notionapi.AppendBlockChildrenResponse, error)
- func (_m *NotionClient) CreateDatabase(_a0 context.Context, _a1 *notionapi.DatabaseCreateRequest) (*notionapi.Database, error)
- func (_m *NotionClient) CreatePage(_a0 context.Context, _a1 *notionapi.PageCreateRequest) (*notionapi.Page, error)
- func (_m *NotionClient) GetAllDatabases(_a0 context.Context, _a1 notionapi.Cursor) ([]notionapi.Database, notionapi.Cursor, error)
- func (_m *NotionClient) GetAllPages(_a0 context.Context, _a1 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)
- func (_m *NotionClient) GetBlockByID(_a0 context.Context, _a1 notionclient.BlockID) (notionapi.Block, error)
- func (_m *NotionClient) GetChildBlocksOfBlock(_a0 context.Context, _a1 notionclient.BlockID, _a2 notionapi.Cursor) ([]notionapi.Block, notionapi.Cursor, error)
- func (_m *NotionClient) GetDatabaseByID(_a0 context.Context, _a1 notionclient.DatabaseID) (*notionapi.Database, error)
- func (_m *NotionClient) GetDatabasePages(_a0 context.Context, _a1 notionclient.DatabaseID, _a2 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)
- func (_m *NotionClient) GetDatabasesByName(_a0 context.Context, _a1 notionclient.DatabaseName, _a2 notionapi.Cursor) ([]notionapi.Database, notionapi.Cursor, error)
- func (_m *NotionClient) GetPageBlocks(_a0 context.Context, _a1 notionclient.PageID, _a2 notionapi.Cursor) ([]notionapi.Block, notionapi.Cursor, error)
- func (_m *NotionClient) GetPageByID(_a0 context.Context, _a1 notionclient.PageID) (*notionapi.Page, error)
- func (_m *NotionClient) GetPagesByName(_a0 context.Context, _a1 notionclient.PageName, _a2 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)
- type ReaderWriter
- func (_m *ReaderWriter) CleanUp(_a0 context.Context) error
- func (_m *ReaderWriter) GetStorageConfig(_a0 context.Context) (*metadata.StorageConfig, error)
- func (_m *ReaderWriter) ReadBlock(_a0 context.Context, _a1 rw.DataIdentifier) (notionapi.Block, error)
- func (_m *ReaderWriter) ReadDatabase(_a0 context.Context, _a1 rw.DataIdentifier) (*notionapi.Database, error)
- func (_m *ReaderWriter) ReadPage(_a0 context.Context, _a1 rw.DataIdentifier) (*notionapi.Page, error)
- func (_m *ReaderWriter) WriteBlock(_a0 context.Context, _a1 notionapi.Block) (rw.DataIdentifier, error)
- func (_m *ReaderWriter) WriteDatabase(_a0 context.Context, _a1 *notionapi.Database) (rw.DataIdentifier, error)
- func (_m *ReaderWriter) WriteMetaData(_a0 context.Context, _a1 *metadata.MetaData) error
- func (_m *ReaderWriter) WritePage(_a0 context.Context, _a1 *notionapi.Page) (rw.DataIdentifier, error)
- type TreeBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigOption ¶
ConfigOption is an autogenerated mock type for the ConfigOption type
func NewConfigOption ¶
func NewConfigOption(t mockConstructorTestingTNewConfigOption) *ConfigOption
NewConfigOption creates a new instance of ConfigOption. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
type Iterator ¶
Iterator is an autogenerated mock type for the Iterator type
func NewIterator ¶
func NewIterator(t mockConstructorTestingTNewIterator) *Iterator
NewIterator creates a new instance of Iterator. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
type NewClient ¶
NewClient is an autogenerated mock type for the NewClient type
func NewNewClient ¶
func NewNewClient(t mockConstructorTestingTNewNewClient) *NewClient
NewNewClient creates a new instance of NewClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
type NotionClient ¶
NotionClient is an autogenerated mock type for the NotionClient type
func NewNotionClient ¶
func NewNotionClient(t mockConstructorTestingTNewNotionClient) *NotionClient
NewNotionClient creates a new instance of NotionClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
func (*NotionClient) AppendBlocksToBlock ¶
func (_m *NotionClient) AppendBlocksToBlock(_a0 context.Context, _a1 notionclient.BlockID, _a2 *notionapi.AppendBlockChildrenRequest) (*notionapi.AppendBlockChildrenResponse, error)
AppendBlocksToBlock provides a mock function with given fields: _a0, _a1, _a2
func (*NotionClient) AppendBlocksToPage ¶
func (_m *NotionClient) AppendBlocksToPage(_a0 context.Context, _a1 notionclient.PageID, _a2 *notionapi.AppendBlockChildrenRequest) (*notionapi.AppendBlockChildrenResponse, error)
AppendBlocksToPage provides a mock function with given fields: _a0, _a1, _a2
func (*NotionClient) CreateDatabase ¶
func (_m *NotionClient) CreateDatabase(_a0 context.Context, _a1 *notionapi.DatabaseCreateRequest) (*notionapi.Database, error)
CreateDatabase provides a mock function with given fields: _a0, _a1
func (*NotionClient) CreatePage ¶
func (_m *NotionClient) CreatePage(_a0 context.Context, _a1 *notionapi.PageCreateRequest) (*notionapi.Page, error)
CreatePage provides a mock function with given fields: _a0, _a1
func (*NotionClient) GetAllDatabases ¶
func (_m *NotionClient) GetAllDatabases(_a0 context.Context, _a1 notionapi.Cursor) ([]notionapi.Database, notionapi.Cursor, error)
GetAllDatabases provides a mock function with given fields: _a0, _a1
func (*NotionClient) GetAllPages ¶
func (_m *NotionClient) GetAllPages(_a0 context.Context, _a1 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)
GetAllPages provides a mock function with given fields: _a0, _a1
func (*NotionClient) GetBlockByID ¶
func (_m *NotionClient) GetBlockByID(_a0 context.Context, _a1 notionclient.BlockID) (notionapi.Block, error)
GetBlockByID provides a mock function with given fields: _a0, _a1
func (*NotionClient) GetChildBlocksOfBlock ¶
func (_m *NotionClient) GetChildBlocksOfBlock(_a0 context.Context, _a1 notionclient.BlockID, _a2 notionapi.Cursor) ([]notionapi.Block, notionapi.Cursor, error)
GetChildBlocksOfBlock provides a mock function with given fields: _a0, _a1, _a2
func (*NotionClient) GetDatabaseByID ¶
func (_m *NotionClient) GetDatabaseByID(_a0 context.Context, _a1 notionclient.DatabaseID) (*notionapi.Database, error)
GetDatabaseByID provides a mock function with given fields: _a0, _a1
func (*NotionClient) GetDatabasePages ¶
func (_m *NotionClient) GetDatabasePages(_a0 context.Context, _a1 notionclient.DatabaseID, _a2 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)
GetDatabasePages provides a mock function with given fields: _a0, _a1, _a2
func (*NotionClient) GetDatabasesByName ¶
func (_m *NotionClient) GetDatabasesByName(_a0 context.Context, _a1 notionclient.DatabaseName, _a2 notionapi.Cursor) ([]notionapi.Database, notionapi.Cursor, error)
GetDatabasesByName provides a mock function with given fields: _a0, _a1, _a2
func (*NotionClient) GetPageBlocks ¶
func (_m *NotionClient) GetPageBlocks(_a0 context.Context, _a1 notionclient.PageID, _a2 notionapi.Cursor) ([]notionapi.Block, notionapi.Cursor, error)
GetPageBlocks provides a mock function with given fields: _a0, _a1, _a2
func (*NotionClient) GetPageByID ¶
func (_m *NotionClient) GetPageByID(_a0 context.Context, _a1 notionclient.PageID) (*notionapi.Page, error)
GetPageByID provides a mock function with given fields: _a0, _a1
func (*NotionClient) GetPagesByName ¶
func (_m *NotionClient) GetPagesByName(_a0 context.Context, _a1 notionclient.PageName, _a2 notionapi.Cursor) ([]notionapi.Page, notionapi.Cursor, error)
GetPagesByName provides a mock function with given fields: _a0, _a1, _a2
type ReaderWriter ¶
ReaderWriter is an autogenerated mock type for the ReaderWriter type
func NewReaderWriter ¶
func NewReaderWriter(t mockConstructorTestingTNewReaderWriter) *ReaderWriter
NewReaderWriter creates a new instance of ReaderWriter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
func (*ReaderWriter) CleanUp ¶
func (_m *ReaderWriter) CleanUp(_a0 context.Context) error
CleanUp provides a mock function with given fields: _a0
func (*ReaderWriter) GetStorageConfig ¶
func (_m *ReaderWriter) GetStorageConfig(_a0 context.Context) (*metadata.StorageConfig, error)
GetStorageConfig provides a mock function with given fields: _a0
func (*ReaderWriter) ReadBlock ¶
func (_m *ReaderWriter) ReadBlock(_a0 context.Context, _a1 rw.DataIdentifier) (notionapi.Block, error)
ReadBlock provides a mock function with given fields: _a0, _a1
func (*ReaderWriter) ReadDatabase ¶
func (_m *ReaderWriter) ReadDatabase(_a0 context.Context, _a1 rw.DataIdentifier) (*notionapi.Database, error)
ReadDatabase provides a mock function with given fields: _a0, _a1
func (*ReaderWriter) ReadPage ¶
func (_m *ReaderWriter) ReadPage(_a0 context.Context, _a1 rw.DataIdentifier) (*notionapi.Page, error)
ReadPage provides a mock function with given fields: _a0, _a1
func (*ReaderWriter) WriteBlock ¶
func (_m *ReaderWriter) WriteBlock(_a0 context.Context, _a1 notionapi.Block) (rw.DataIdentifier, error)
WriteBlock provides a mock function with given fields: _a0, _a1
func (*ReaderWriter) WriteDatabase ¶
func (_m *ReaderWriter) WriteDatabase(_a0 context.Context, _a1 *notionapi.Database) (rw.DataIdentifier, error)
WriteDatabase provides a mock function with given fields: _a0, _a1
func (*ReaderWriter) WriteMetaData ¶
WriteMetaData provides a mock function with given fields: _a0, _a1
func (*ReaderWriter) WritePage ¶
func (_m *ReaderWriter) WritePage(_a0 context.Context, _a1 *notionapi.Page) (rw.DataIdentifier, error)
WritePage provides a mock function with given fields: _a0, _a1
type TreeBuilder ¶
TreeBuilder is an autogenerated mock type for the TreeBuilder type
func NewTreeBuilder ¶
func NewTreeBuilder(t mockConstructorTestingTNewTreeBuilder) *TreeBuilder
NewTreeBuilder creates a new instance of TreeBuilder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.