Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrDone = fmt.Errorf("no more items in iterator")
Done is returned by an iterator's Next method when the iteration is complete; when there are no more items to return. Every Iterator type extending Iterator interface must return this error when there are no more items to iterate
Functions ¶
This section is empty.
Types ¶
type ChildIterator ¶
type ChildIterator struct {
// contains filtered or unexported fields
}
ChildIterator would iterate only it's children and not grandchildren
type Iterator ¶
Every Iterator type must extend this interface while implementing the iterator
func GetChildIterator ¶
func GetTreeIterator ¶
type ParentIterator ¶
type ParentIterator struct {
// contains filtered or unexported fields
}
func GetParentIterator ¶
func GetParentIterator(nodeObj *node.Node) *ParentIterator
type TreeIterator ¶
type TreeIterator struct {
// contains filtered or unexported fields
}
TreeIterator would iterate the whole tree or subtree depending on the node passed to the iterator. If root node is passed, whole tree would be iterated else the subtree of given node would be iterated
Click to show internal directories.
Click to hide internal directories.